@@ -1,4 +1,6 @@
+from pprint import pformat
 import logging
+import os
 
 from django.contrib.auth import login as auth_login, get_user_model
 from django.contrib.auth.base_user import BaseUserManager
@@ -9,6 +11,9 @@ from netbox.authentication import RemoteUserBackend
 import requests
 
 PLUGIN_SETTINGS = settings.PLUGINS_CONFIG["netbox_plugin_azuread"]
+
+LOGLEVEL = os.environ.get('LOGLEVEL', 'INFO').upper()
+logging.basicConfig(level=LOGLEVEL)
 LOGGER = logging.getLogger("netbox_plugin_azuread")
 
 
@@ -43,16 +48,21 @@ class AzureADRemoteUserBackend(RemoteUserBackend):
 
     def retrieve_user(self, auth_result):
         access_token = self.acquire_client_token()
+        LOGGER.debug(f"Received an access token for the user: {access_token}")
+        LOGGER.debug(f"Claims map looks as follows: {pformat(auth_result)}")
         claims = auth_result.get('id_token_claims')
         try:
             user = get_user_model().objects.get(username=claims.get('preferred_username'))
-        except Exception:
+            LOGGER.debug(f"Retrieved user: {pformat(user)}")
+        except Exception as ex:
+            LOGGER.debug(f"Failed to find a user. Attempting to create a user from scratch: {ex}")
             user = self._create_user_from_claims(claims, access_token)
         self._configure_access_groups(user, access_token) # groups change over time so we check each login
         return user
 
     def _create_user_from_claims(self, claims, access_token):
         username = claims.get('preferred_username')
+        LOGGER.debug(f"Creating a user with the username {username}")
         profile = self._get_user_profile(username, access_token)
         password = BaseUserManager().make_random_password()
         user = User(
@@ -63,24 +73,29 @@ class AzureADRemoteUserBackend(RemoteUserBackend):
             last_name=profile.get('surname', '')
         )
         user.save()
+        LOGGER.debug("New user created")
         return user
 
     def _retrieve_user_groups(self, user_id, access_token):
+        LOGGER.debug(f"Attempting to retrieve groups for user with id {user_id}")
         groups_url = f'https://graph.microsoft.com/v1.0/users/{user_id}/memberOf?$select=displayName,id'
         headers = {
             'Authorization': f'Bearer {access_token}',
             'Content-Type': 'application/json'
         }
         r = requests.get(groups_url, headers=headers)
+        LOGGER.debug(f"Retrieved groups for {user_id} from MS Graph: {pformat(r.json())}")
         return r.json().get('value', [])
 
     def _configure_access_groups(self, user, access_token):
-        user_id = self._get_user_profile(user.username, access_token).get('id')
+        user_profile = self._get_user_profile(user.username, access_token)
+        user_id = user_profile.get('id')
         azure_groups = self._retrieve_user_groups(user_id, access_token)
         user.is_staff = False
         user.is_superuser = False # Recheck user still has these permissions each time
         # TODO: Remove user from all groups if no groups found in Azure
         if azure_groups:
+            LOGGER.debug(f"This user is part of {len(azure_groups)} azure groups")
             azure_group_names = [entry.get('displayName') for entry in azure_groups]
             AD_GROUP_MAP = PLUGIN_SETTINGS.get('AD_GROUP_MAP', {})
             for group_name in azure_group_names:
@@ -107,21 +122,25 @@ class AzureADRemoteUserBackend(RemoteUserBackend):
         return user
 
     def _get_user_profile(self, username, access_token):
+        LOGGER.debug(f"Retrieving user profile for {username}")
         profile_url = f'https://graph.microsoft.com/v1.0/users/{username}'
         headers = {
             'Authorization': f'Bearer {access_token}',
             'Content-Type': 'application/json'
         }
         r = requests.get(profile_url, headers=headers)
+        LOGGER.debug(f"Retrieved profile for {username} from MS Graph: {pformat(r.json())}")
         return r.json()
 
     def get_auth_url(self, redirect_url, state=None):
         client = self._create_msal_client()
-        return client.get_authorization_request_url(
+        auth_url = client.get_authorization_request_url(
             scopes=PLUGIN_SETTINGS["SCOPES"],
             state=state,
             redirect_uri=redirect_url
         )
+        LOGGER.debug(f"Generated auth url: {auth_url}")
+        return auth_url
 
     def _load_cache(self, request):
         cache = msal.SerializableTokenCache()
